Learn R Programming

Rcolombos (version 2.0.2)

listOrganisms: Returns a character vector corresponding to the currently available organisms.

Description

Returns a character vector corresponding to the currently available organisms.

Usage

listOrganisms()

Arguments

Value

A list containing the currently available organisms.

References

http://colombos.net

Examples

Run this code
library('Rcolombos')
listOrganisms()

Run the code above in your browser using DataLab