Arguments
organism
A character containing the organism id: use listOrganisms to display
the available organisms. g_ids
A vector of strings representing contrast_id, go terms, experiment id or condition id according the search type.
geneNames
boolean if == FALSE (default) return the locustag otherwise the gene_name for the selected genes.
c_ids
A vector of strings representing contrast_id, go terms, experiment id or condition id according the search type.
g_search_type
A string either genes, go or annotation.
ann_type
A string containing the selected gene_annotation_type: use listEntities to display the available entities. c_search_type
A string either contrast_names. experiment, go, condition.